==> gi-assets-algorithm-2.0.0.tgz: package/es/NodesSimilarity/Component.js <==
function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }
function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }
function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(arr, i) { var _i = null == arr ? null : "undefined" != typeof Symbol && arr[Symbol.iterator] || arr["@@iterator"]; if (null != _i) { var _s, _e, _x, _r, _arr = [], _n = !0, _d = !1; try { if (_x = (_i = _i.call(arr)).next, 0 === i) { if (Object(_i) !== _i) return; _n = !1; } else for (; !(_n = (_s = _x.call(_i)).done) && (_arr.push(_s.value), _arr.length !== i); _n = !0); } catch (err) { _d = !0, _e = err; } finally { try { if (!_n && null != _i.return && (_r = _i.return(), Object(_r) !== _r)) return; } finally { if (_d) throw _e; } } return _arr; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
import { FormOutlined, ReloadOutlined } from '@ant-design/icons';
import { nodesCosineSimilarity } from '@antv/algorithm';
import { useContext } from '@antv/gi-sdk';
import { Button, Col, Empty, Input, message, Radio, Row } from 'antd';
import { cloneDeep } from 'lodash';
import React, { useEffect, useState } from 'react';
import './index.less';
import FormattedMessage, { formatMessage } from './locale';
import SimilarityResultTable from './resultTable';
export var NodesSimilarityAlgorithm;
(function (NodesSimilarityAlgorithm) {
  NodesSimilarityAlgorithm["nodesConsineSimilarity"] = "nodes-cosine-similarity";
})(NodesSimilarityAlgorithm || (NodesSimilarityAlgorithm = {}));
var CommunityDiscovery = function CommunityDiscovery(props) {
  var _props$style = props.style,
    style = _props$style === void 0 ? {} : _props$style;
  var context = useContext();
  var data = context.data,
    graph = context.graph;
  var _useState = useState(NodesSimilarityAlgorithm.nodesConsineSimilarity),
    _useState2 = _slicedToArray(_useState, 2),
    communityAlgo = _useState2[0],
    setCommunityAlgo = _useState2[1];
  var _useState3 = useState({
      nodes: [],
      edges: []
    }),
    _useState4 = _slicedToArray(_useState3, 2),
    initData = _useState4[0],
    setInitData = _useState4[1];
  var _useState5 = useState(NodesSimilarityAlgorithm.nodesConsineSimilarity),
    _useState6 = _slicedToArray(_useState5, 2),
    similarityAlgo = _useState6[0],
    setSimilarityAlgo = _useState6[1];
  var _useState7 = useState({
      similarityRes: [],
      similarNodes: []
    }),
    _useState8 = _slicedToArray(_useState7, 2),
    resData = _useState8[0],
    setResData = _useState8[1];
  var _useState9 = useState(false),
    _useState10 = _slicedToArray(_useState9, 2),
    hasAnalysis = _useState10[0],
    setHasAnalysis = _useState10[1];
  var _useState11 = useState(null),
    _useState12 = _slicedToArray(_useState11, 2),
    seedNodeId = _useState12[0],
    setSeedNodeId = _useState12[1];
  var _useState13 = useState(false),
    _useState14 = _slicedToArray(_useState13, 2),
    topReset = _useState14[0],
    setTopReset = _useState14[1];
  var _useState15 = useState(false),
    _useState16 = _slicedToArray(_useState15, 2),
    selecting = _useState16[0],
    setSelecting = _useState16[1];
  var nodeClickListener = function nodeClickListener(e) {};
  useEffect(function () {
    setInitData({
      //@ts-ignore
      nodes: cloneDeep(graph.getNodes()).map(function (node) {
        return node.getModel();
      }),
      //@ts-ignore
      edges: cloneDeep(graph.getEdges()).map(function (edge) {
        var model = edge.getModel();
        return Object.assign(Object.assign({}, model), {
          //@ts-ignore
          id: model.id || model.data.id
        });
      })
    });
  }, [data]);
  var similarityAlgoSelections = [{
    name: NodesSimilarityAlgorithm.nodesConsineSimilarity,
    content: /*#__PURE__*/React.createElement(React.Fragment, null)
  }];
  var resetMapping = function resetMapping(mappedNodeIds, mappedEdgeIds) {
    graph.getNodes().forEach(function (node) {
      var _a, _b, _c;
      var id = node.get('id');
      var initModel = (_a = initData.nodes) === null || _a === void 0 ? void 0 : _a.find(function (initNode) {
        return initNode.id === id;
      });
      if (initModel && !(mappedNodeIds === null || mappedNodeIds === void 0 ? void 0 : mappedNodeIds.includes(id))) {
        graph.updateItem(node, {
          style: {
            keyshape: {
              size: (_c = (_b = initModel.style) === null || _b === void 0 ? void 0 : _b.keyshape) === null || _c === void 0 ? void 0 : _c.size
            }
          }
        });
      }
    });
    graph.getEdges().forEach(function (edge) {
      edge.refresh();
    });
  };
  var formatOriginData = function formatOriginData(_ref) {
    var _ref$nodes = _ref.nodes,
      nodes = _ref$nodes === void 0 ? [] : _ref$nodes,
      _ref$edges = _ref.edges,
      edges = _ref$edges === void 0 ? [] : _ref$edges;
    return {
      nodes: nodes.map(function (node) {
        return {
          id: node.id,
          label: node.label || node.data.label,
          properties: node.data.properties
        };
      }),
      edges: edges.map(function (edge) {
        return Object.assign(Object.assign({}, edge), {
          id: edge.id || edge.data.id
        });
      })
    };
  };
  var setNodeStyle = function setNodeStyle(nodes, similarityKey) {
    nodes.forEach(function (node) {
      graph.updateItem(node.id, {
        style: {
          keyshape: {
            size: Math.max(50 * node[similarityKey], 30)
          }
        }
      });
    });
    graph.getEdges().forEach(function (edge) {
      edge.refresh();
    });
  };
  var onAnalyse = function onAnalyse() {
    setSelecting(false);
    setHasAnalysis(true);
    var formatData = formatOriginData(data);
    switch (similarityAlgo) {
      case NodesSimilarityAlgorithm.nodesConsineSimilarity:
        if (!graph || graph.destroyed) {
          return;
        }
        var nodes = (formatData === null || formatData === void 0 ? void 0 : formatData.nodes) || [];
        var seedNode = nodes === null || nodes === void 0 ? void 0 : nodes.find(function (node) {
          return node.id === seedNodeId;
        });
        if (!seedNode) {
          message.info(formatMessage({
            id: 'seed-node-not-found'
          }));
        }
        // @ts-ignore
        var _nodesCosineSimilarit = nodesCosineSimilarity(nodes, seedNode, 'properties'),
          allCosineSimilarity = _nodesCosineSimilarit.allCosineSimilarity,
          similarNodes = _nodesCosineSimilarit.similarNodes;
        setResData({
          similarityRes: allCosineSimilarity,
          similarNodes: [seedNode].concat(_toConsumableArray(similarNodes))
        });
        console.log('set node style', similarNodes);
        setNodeStyle(similarNodes, 'cosineSimilarity');
        break;
      default:
        break;
    }
  };
  var renderResult = function renderResult() {
    if (!hasAnalysis) {
      return;
    }
    var _ref2 = resData || {},
      similarityRes = _ref2.similarityRes,
      similarNodes = _ref2.similarNodes;
    if (!(similarityRes === null || similarityRes === void 0 ? void 0 : similarityRes.length)) {
      return /*#__PURE__*/React.createElement(Empty, {
        image: Empty.PRESENTED_IMAGE_SIMPLE,
        description: /*#__PURE__*/React.createElement(FormattedMessage, {
          id: "data.no-data"
        })
      });
    }
    if (similarityAlgo === NodesSimilarityAlgorithm.nodesConsineSimilarity) {
      return /*#__PURE__*/React.createElement("div", {
        className: "nodes-similarity-result-wrapper"
      }, /*#__PURE__*/React.createElement("span", {
        className: "nodes-similarity-title"
      }, /*#__PURE__*/React.createElement(FormattedMessage, {
        id: "analysis-result"
      })), /*#__PURE__*/React.createElement(SimilarityResultTable, {
        similarNodes: similarNodes,
        topReset: topReset,
        similarityKey: "cosineSimilarity"
      }));
    }
  };
  var changeAlgo = function changeAlgo(e) {
    resetMapping([], []);
    setResData({
      similarityRes: [],
      similarNodes: []
    });
    setCommunityAlgo(e.target.value);
  };
  var reset = function reset() {
    resetMapping([], []);
    setResData({
      similarityRes: [],
      similarNodes: []
    });
    setCommunityAlgo(NodesSimilarityAlgorithm.nodesConsineSimilarity);
    setTopReset(true);
  };
  var onSeachSeed = function onSeachSeed(e) {
    setSelecting(false);
    var nodeId = typeof e === 'string' ? e : e.target.value;
    setSeedNodeId(nodeId);
    if (graph.findById(nodeId)) {
      graph.updateItem(nodeId, {
        style: {
          keyshape: {
            size: 40
          }
        }
      });
      graph.getEdges().forEach(function (edge) {
        edge.refresh();
      });
    }
  };
  var beginSelect = function beginSelect() {
    setSelecting(true);
    graph.off('node:click', nodeClickListener);
    nodeClickListener = function nodeClickListener(e) {
      setSelecting(false);
      var item = e.item;
      if (!item || item.destroyed) return;
      onSeachSeed(item.getID());
      // setSeedNodeId(item.getID());
    };

    graph.once('node:click', nodeClickListener);
  };
  return /*#__PURE__*/React.createElement("div", {
    style: Object.assign({}, style)
  }, /*#__PURE__*/React.createElement("div", {
    className: "nodes-similarity-wrapper"
  }, /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement("p", {
    className: "nodes-similarity-title"
  }, /*#__PURE__*/React.createElement(FormattedMessage, {
    id: "itelligent-analysis.nodes-similarity.select-seed-node"
  })), /*#__PURE__*/React.createElement(Row, {
    justify: "space-between"
  }, /*#__PURE__*/React.createElement(Col, {
    span: 22
  }, /*#__PURE__*/React.createElement(Input, {
    placeholder: formatMessage({
      id: 'itelligent-analysis.nodes-similarity.select-seed-node'
    }),
    style: {
      display: 'block',
      margin: '0 0 30px 10px'
    },
    onChange: onSeachSeed,
    //@ts-ignore
    value: seedNodeId
  })), /*#__PURE__*/React.createElement(Col, {
    span: 2,
    style: {
      lineHeight: '32px',
      textAlign: 'right'
    }
  }, /*#__PURE__*/React.createElement(FormOutlined, {
    style: {
      cursor: 'pointer',
      color: selecting ? '#1890ff' : 'rgba(0, 0, 0, 0.65)'
    },
    onClick: beginSelect
  })))), /*#__PURE__*/React.createElement("div", {
    className: "top-info"
  }, /*#__PURE__*/React.createElement("p", {
    className: "nodes-similarity-title"
  }, /*#__PURE__*/React.createElement(FormattedMessage, {
    id: "itelligent-analysis.select-algo"
  })), /*#__PURE__*/React.createElement(ReloadOutlined, {
    onClick: reset
  })), /*#__PURE__*/React.createElement(Radio.Group, {
    onChange: changeAlgo,
    value: communityAlgo
  }, similarityAlgoSelections.map(function (selection) {
    return /*#__PURE__*/React.createElement("div", {
      key: selection.name
    }, /*#__PURE__*/React.createElement(Radio, {
      value: selection.name,
      className: "nodes-similarity-algo-radio"
    }, /*#__PURE__*/React.createElement("div", {
      className: "nodes-similarity-algo-title"
    }, /*#__PURE__*/React.createElement("span", {
      className: "nodes-similarity-algo-title-name"
    }, /*#__PURE__*/React.createElement(FormattedMessage, {
      id: "itelligent-analysis.nodes-similarity.".concat(selection.name)
    })), /*#__PURE__*/React.createElement("span", {
      className: "nodes-similarity-algo-title-tip"
    }, /*#__PURE__*/React.createElement(FormattedMessage, {
      id: "itelligent-analysis.nodes-similarity.".concat(selection.name, "-tip")
    })))), selection.content);
  })), /*#__PURE__*/React.createElement(Button, {
    type: "primary",
    style: {
      width: '100%',
      marginTop: '12px'
    },
    onClick: onAnalyse
  }, /*#__PURE__*/React.createElement(FormattedMessage, {
    id: "analyse"
  })), renderResult()));
};
export default CommunityDiscovery;

==> gi-assets-algorithm-2.0.1.tgz: package/es/NodesSimilarity/Component.js <==
function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }
function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && iter[Symbol.iterator] != null || iter["@@iterator"] != null) return Array.from(iter); }
function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(arr, i) { var _i = null == arr ? null : "undefined" != typeof Symbol && arr[Symbol.iterator] || arr["@@iterator"]; if (null != _i) { var _s, _e, _x, _r, _arr = [], _n = !0, _d = !1; try { if (_x = (_i = _i.call(arr)).next, 0 === i) { if (Object(_i) !== _i) return; _n = !1; } else for (; !(_n = (_s = _x.call(_i)).done) && (_arr.push(_s.value), _arr.length !== i); _n = !0); } catch (err) { _d = !0, _e = err; } finally { try { if (!_n && null != _i.return && (_r = _i.return(), Object(_r) !== _r)) return; } finally { if (_d) throw _e; } } return _arr; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
import { FormOutlined, ReloadOutlined } from '@ant-design/icons';
import { nodesCosineSimilarity } from '@antv/algorithm';
import { useContext } from '@antv/gi-sdk';
import { Button, Col, Empty, Input, message, Row } from 'antd';
import { cloneDeep } from 'lodash';
import React, { useEffect, useState } from 'react';
import './index.less';
import FormattedMessage, { formatMessage } from './locale';
import SimilarityResultTable from './resultTable';
export var NodesSimilarityAlgorithm;
(function (NodesSimilarityAlgorithm) {
  NodesSimilarityAlgorithm["nodesConsineSimilarity"] = "nodes-cosine-similarity";
})(NodesSimilarityAlgorithm || (NodesSimilarityAlgorithm = {}));
var CommunityDiscovery = function CommunityDiscovery(props) {
  var _props$style = props.style,
    style = _props$style === void 0 ? {} : _props$style;
  var context = useContext();
  var data = context.data,
    graph = context.graph;
  var _useState = useState(NodesSimilarityAlgorithm.nodesConsineSimilarity),
    _useState2 = _slicedToArray(_useState, 2),
    communityAlgo = _useState2[0],
    setCommunityAlgo = _useState2[1];
  var _useState3 = useState({
      nodes: [],
      edges: []
    }),
    _useState4 = _slicedToArray(_useState3, 2),
    initData = _useState4[0],
    setInitData = _useState4[1];
  var _useState5 = useState(NodesSimilarityAlgorithm.nodesConsineSimilarity),
    _useState6 = _slicedToArray(_useState5, 2),
    similarityAlgo = _useState6[0],
    setSimilarityAlgo = _useState6[1];
  var _useState7 = useState({
      similarityRes: [],
      similarNodes: []
    }),
    _useState8 = _slicedToArray(_useState7, 2),
    resData = _useState8[0],
    setResData = _useState8[1];
  var _useState9 = useState(false),
    _useState10 = _slicedToArray(_useState9, 2),
    hasAnalysis = _useState10[0],
    setHasAnalysis = _useState10[1];
  var _useState11 = useState(null),
    _useState12 = _slicedToArray(_useState11, 2),
    seedNodeId = _useState12[0],
    setSeedNodeId = _useState12[1];
  var _useState13 = useState(false),
    _useState14 = _slicedToArray(_useState13, 2),
    topReset = _useState14[0],
    setTopReset = _useState14[1];
  var _useState15 = useState(false),
    _useState16 = _slicedToArray(_useState15, 2),
    selecting = _useState16[0],
    setSelecting = _useState16[1];
  var nodeClickListener = function nodeClickListener(e) {};
  useEffect(function () {
    setInitData({
      //@ts-ignore
      nodes: cloneDeep(graph.getNodes()).map(function (node) {
        return node.getModel();
      }),
      //@ts-ignore
      edges: cloneDeep(graph.getEdges()).map(function (edge) {
        var model = edge.getModel();
        return Object.assign(Object.assign({}, model), {
          //@ts-ignore
          id: model.id || model.data.id
        });
      })
    });
  }, [data]);
  var resetMapping = function resetMapping(mappedNodeIds, mappedEdgeIds) {
    graph.getNodes().forEach(function (node) {
      var _a, _b, _c;
      var id = node.get('id');
      var initModel = (_a = initData.nodes) === null || _a === void 0 ? void 0 : _a.find(function (initNode) {
        return initNode.id === id;
      });
      if (initModel && !(mappedNodeIds === null || mappedNodeIds === void 0 ? void 0 : mappedNodeIds.includes(id))) {
        graph.updateItem(node, {
          style: {
            keyshape: {
              size: (_c = (_b = initModel.style) === null || _b === void 0 ? void 0 : _b.keyshape) === null || _c === void 0 ? void 0 : _c.size
            }
          }
        });
      }
    });
    graph.getEdges().forEach(function (edge) {
      edge.refresh();
    });
  };
  var formatOriginData = function formatOriginData(_ref) {
    var _ref$nodes = _ref.nodes,
      nodes = _ref$nodes === void 0 ? [] : _ref$nodes,
      _ref$edges = _ref.edges,
      edges = _ref$edges === void 0 ? [] : _ref$edges;
    return {
      nodes: nodes.map(function (node) {
        var properties = Object.assign({}, node.data, node.data.properties);
        delete properties.id;
        return {
          id: node.id,
          label: node.label || node.data.label,
          properties: properties
        };
      }),
      edges: edges.map(function (edge) {
        return Object.assign(Object.assign({}, edge), {
          id: edge.id || edge.data.id
        });
      })
    };
  };
  var setNodeStyle = function setNodeStyle(nodes, similarityKey) {
    nodes.forEach(function (node) {
      graph.updateItem(node.id, {
        style: {
          keyshape: {
            size: Math.max(50 * node[similarityKey], 30)
          }
        }
      });
    });
    graph.getEdges().forEach(function (edge) {
      edge.refresh();
    });
  };
  var onAnalyse = function onAnalyse() {
    setSelecting(false);
    setHasAnalysis(true);
    var formatData = formatOriginData(data);
    switch (similarityAlgo) {
      case NodesSimilarityAlgorithm.nodesConsineSimilarity:
        if (!graph || graph.destroyed) {
          return;
        }
        var nodes = (formatData === null || formatData === void 0 ? void 0 : formatData.nodes) || [];
        var seedNode = nodes === null || nodes === void 0 ? void 0 : nodes.find(function (node) {
          return node.id === seedNodeId;
        });
        if (!seedNode) {
          message.info(formatMessage({
            id: 'seed-node-not-found'
          }));
        }
        // @ts-ignore
        var _nodesCosineSimilarit = nodesCosineSimilarity(nodes, seedNode, 'properties'),
          allCosineSimilarity = _nodesCosineSimilarit.allCosineSimilarity,
          similarNodes = _nodesCosineSimilarit.similarNodes;
        setResData({
          similarityRes: allCosineSimilarity,
          similarNodes: [seedNode].concat(_toConsumableArray(similarNodes))
        });
        setNodeStyle(similarNodes, 'cosineSimilarity');
        break;
      default:
        break;
    }
  };
  var renderResult = function renderResult() {
    if (!hasAnalysis) {
      return;
    }
    var _ref2 = resData || {},
      similarityRes = _ref2.similarityRes,
      similarNodes = _ref2.similarNodes;
    if (!(similarityRes === null || similarityRes === void 0 ? void 0 : similarityRes.length)) {
      return /*#__PURE__*/React.createElement(Empty, {
        image: Empty.PRESENTED_IMAGE_SIMPLE,
        description: /*#__PURE__*/React.createElement(FormattedMessage, {
          id: "data.no-data"
        })
      });
    }
    if (similarityAlgo === NodesSimilarityAlgorithm.nodesConsineSimilarity) {
      return /*#__PURE__*/React.createElement("div", {
        className: "nodes-similarity-result-wrapper"
      }, /*#__PURE__*/React.createElement("span", {
        className: "nodes-similarity-title"
      }, /*#__PURE__*/React.createElement(FormattedMessage, {
        id: "analysis-result"
      })), /*#__PURE__*/React.createElement(SimilarityResultTable, {
        similarNodes: similarNodes,
        topReset: topReset,
        similarityKey: "cosineSimilarity"
      }));
    }
  };
  var reset = function reset() {
    resetMapping([], []);
    setResData({
      similarityRes: [],
      similarNodes: []
    });
    setCommunityAlgo(NodesSimilarityAlgorithm.nodesConsineSimilarity);
    setTopReset(true);
  };
  var onSeachSeed = function onSeachSeed(e) {
    setSelecting(false);
    var nodeId = typeof e === 'string' ? e : e.target.value;
    setSeedNodeId(nodeId);
    if (graph.findById(nodeId)) {
      graph.updateItem(nodeId, {
        style: {
          keyshape: {
            size: 40
          }
        }
      });
      graph.getEdges().forEach(function (edge) {
        edge.refresh();
      });
    }
  };
  var beginSelect = function beginSelect() {
    setSelecting(true);
    graph.off('node:click', nodeClickListener);
    nodeClickListener = function nodeClickListener(e) {
      setSelecting(false);
      var item = e.item;
      if (!item || item.destroyed) return;
      onSeachSeed(item.getID());
      // setSeedNodeId(item.getID());
    };

    graph.once('node:click', nodeClickListener);
  };
  return /*#__PURE__*/React.createElement("div", {
    style: Object.assign({}, style)
  }, /*#__PURE__*/React.createElement("div", {
    className: "nodes-similarity-wrapper"
  }, /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(Row, {
    justify: "space-between"
  }, /*#__PURE__*/React.createElement(Col, {
    span: 21
  }, /*#__PURE__*/React.createElement("p", {
    className: "nodes-similarity-title"
  }, /*#__PURE__*/React.createElement(FormattedMessage, {
    id: "itelligent-analysis.nodes-similarity.select-seed-node"
  }))), /*#__PURE__*/React.createElement(Col, {
    span: 2,
    offset: 1,
    style: {
      lineHeight: '32px',
      textAlign: 'right'
    }
  }, /*#__PURE__*/React.createElement(ReloadOutlined, {
    onClick: reset
  }))), /*#__PURE__*/React.createElement(Row, {
    justify: "space-between"
  }, /*#__PURE__*/React.createElement(Col, {
    span: 21
  }, /*#__PURE__*/React.createElement(Input, {
    placeholder: formatMessage({
      id: 'itelligent-analysis.nodes-similarity.select-seed-node'
    }),
    style: {
      display: 'block',
      margin: '0 0 30px 10px'
    },
    onChange: onSeachSeed,
    //@ts-ignore
    value: seedNodeId
  })), /*#__PURE__*/React.createElement(Col, {
    span: 2,
    offset: 1,
    style: {
      lineHeight: '32px',
      textAlign: 'right'
    }
  }, /*#__PURE__*/React.createElement(FormOutlined, {
    style: {
      cursor: 'pointer',
      color: selecting ? '#1890ff' : 'rgba(0, 0, 0, 0.65)'
    },
    onClick: beginSelect
  })))), /*#__PURE__*/React.createElement(Button, {
    type: "primary",
    style: {
      width: '100%',
      marginTop: '12px'
    },
    onClick: onAnalyse
  }, /*#__PURE__*/React.createElement(FormattedMessage, {
    id: "analyse"
  })), renderResult()));
};
export default CommunityDiscovery;
